package de.intevation.flys.client.shared.model;

import java.io.Serializable;


/**
 * This class represents an artifact for the client. It contains the necessary
 * information for the client and the communication with the artifact server.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public interface Artifact extends Serializable {

    /**
     * Returns the UUID of the artifact.
     *
     * @return the UUID.
     */
    public String getUuid();


    /**
     * Returns the hash of the artifact.
     *
     * @return the hash.
     */
    public String getHash();


    /**
     * Returns the ArtifactDescription.
     *
     * @return the artifact description.
     */
    public ArtifactDescription getArtifactDescription();


    /**
     * Sets a new ArtifactDescription.
     *
     * @param artifactDescription The new artifact description.
     */
    public void setArtifactDescription(ArtifactDescription artifactDescription);
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
